@@ -29,12 +29,12 @@
 #warning The C++ ABI version of compiler you are using does not exactly match
 #warning that of the compiler used to build the library. If linking fails
 #warning due to missing symbols, this is probably the reason why.
-#warning The Xapian library was built with g++ 8.2.0
+#warning The Xapian library was built with g++ 8.2.1
 #else
 #error The C++ ABI version of compiler you are using does not match
 #error that of the compiler used to build the library. The versions
 #error must match or your program will not work correctly.
-#error The Xapian library was built with g++ 8.2.0
+#error The Xapian library was built with g++ 8.2.1
 #endif
 #endif
 
@@ -50,7 +50,7 @@
 #define XAPIAN_ENABLE_VISIBILITY
 
 /// The version of Xapian as a C string literal.
-#define XAPIAN_VERSION "1.4.7"
+#define XAPIAN_VERSION "1.4.10"
 
 /** The major component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 1
@@ -65,7 +65,7 @@
 /** The revision component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 14
  */
-#define XAPIAN_REVISION 7
+#define XAPIAN_REVISION 10
 
 /// Base (signed) type for Xapian::docid and related types.
 #define XAPIAN_DOCID_BASE_TYPE int
@@ -73,6 +73,9 @@
 /// Base (signed) type for Xapian::termcount and related types.
 #define XAPIAN_TERMCOUNT_BASE_TYPE int
 
+/// Base (signed) type for Xapian::termpos.
+#define XAPIAN_TERMPOS_BASE_TYPE int
+
 /// Type for returning total document length.
 #define XAPIAN_TOTALLENGTH_TYPE unsigned long long
 
